@@ -7,6 +7,6 @@ mmvm.mle <- function(x, N, rads = FALSE) {
     - k * sum( cos(N * (x - m) ) ) + n * log(2 * pi) + n * ( log( besselI(k, 0, expon.scaled = TRUE) ) - k )
   }
 
-  qa <- optim( c(mean(x), 1), likel, x = x, N = N, n = n, control = list(maxit = 5000) )
+  qa <- optim( c(mean(x), 1), likel, x = x, N = N, n = n, control = list(maxit = 5000), method = "BFGS" )
   list(mu = qa$par[1], kappa = exp(qa$par[2]), loglik = -qa$value )
 }
