@@ -17,14 +17,20 @@ watson <- function(u, rads = FALSE, R = 1) {
 
   if ( R == 1 ) {  ## asymptotic p-value is returned
     m <- 1:20
-    pvalue <- 2 * sum( ( - 1 )^( m - 1 ) * exp(-2 * m^2 * pi^2 * Wn) )
+    p.value <- 2 * sum( ( - 1 )^( m - 1 ) * exp(-2 * m^2 * pi^2 * Wn) )
   } else {
     x <- matrix( Rfast2::Runif(n * R, 0, 2 * pi), ncol = R )
     x <- Rfast::colSort(x) / (2 * pi)
     bwn <- Rfast::colMaxs(x - (i - 1)/n, value = TRUE) + Rfast::colMaxs(i/n - x, value = TRUE)
-    pvalue <- ( sum(bwn > Wn) + 1 ) / (R + 1)
+    p.value <- ( sum(bwn > Wn) + 1 ) / (R + 1)
   }
-  res <- c(Wn, pvalue)
-  names(res) <- c("Test", "p-value")
-  res
+
+  parameter <- "NA"     ;   names(parameter) <- "df"
+  statistic <- Wn  ;   names(statistic) <- "Test statistic"
+  alternative <- "The distribution is circular uniform"
+  method <- "Watson test of uniformity with circular data"
+  data.name <- c("data")
+  result <- list( statistic = statistic, parameter = parameter, p.value = p.value,
+                  alternative = alternative, method = method, data.name = data.name )
+  class(result) <- "htest"
 }
